version 17
clear all

/* New -- putdocx commands for creating document, adding headings, 
   and adding paragraph text */
putdocx begin

putdocx paragraph, style(Heading1)
putdocx text ("Introduction")

putdocx textblock begin, hardbreak
This study examines relationships between high blood pressure and
a number of demographic and health measures.
putdocx textblock end

putdocx paragraph, style(Heading1)
putdocx text ("Data")

putdocx textblock begin, hardbreak
We use data from the Second National Health and Nutrition Examination Survey.  
Table 1 below reports summary statistics for individuals with and
without high blood pressure.
putdocx textblock end

/* Old -- Table 1 that we created using -table- and -collect- */
webuse nhanes2l, clear
table (var) (highbp),                        ///
  statistic(mean age bmi)                    ///
  statistic(sd age bmi)                      ///
  statistic(fvfrequency sex race hlthstat)   ///
  statistic(fvpercent sex race hlthstat)     ///
  statistic(mean tcresult tgresult hdresult) ///
  statistic(sd tcresult tgresult hdresult)   ///
  nformat(%5.2f mean sd)                     ///
  sformat("(%s%%)" fvpercent)                ///
  sformat("(%s)" sd)

collect composite define mystat = mean sd fvfrequency fvpercent, trim
collect style header result, level(hide)
collect layout (var) (highbp#result[mystat])
collect style row stack, nobinder spacer
collect label dim highbp "Hypertension", modify
collect label levels highbp 0 "No" 1 "Yes"
collect notes 1: Mean and standard deviation reported for continuous variables.
collect notes 2: Frequency and percentage reported for categorical variables.
collect title "Table 1: Summary statistics"

/* New -- Add table to the document */
putdocx collect

/* New -- Add another heading and paragraph text */
putdocx paragraph, style(Heading1)
putdocx text ("Results")

putdocx textblock begin, hardbreak
We fit three logistic regression models of high blood pressure on BMI, 
age, sex, and the interaction of age and sex.  Results of the three
models are presented in Table 2.
putdocx textblock end

/* Old -- Estimation table created with -etable- and -collect- */
logistic highbp bmi age 
etable
logistic highbp bmi age i.sex
etable, append
logistic highbp bmi c.age##i.sex
etable, append column(index)                     ///
  mstat(aic) mstat(bic)                          ///
  title("Table 2: Logistic regression results")  ///
  notes("Odds ratio (Std. Err.)")
collect style header sex, title(hide)
collect style row split, dups(first) delimiter(" x ") spacer 
collect preview

/* New -- Add table to the document */
putdocx collect

/* New -- Add more text and a graph; save the document */
putdocx textblock begin, hardbreak
The model with the interaction provided best fit. The graph below
plots explores the interaction effect. Probability of high blood
pressure increases with age. For younger individuals, males
have a higher probability of having high blood pressure, but this
changes with age. 
putdocx textblock end

margins sex, at(age=(20(5)75))
marginsplot, ytitle("Probability of high blood pressure") ///
  title("Interaction of age and sex")                     ///
  graphregion(fcolor(white))                              ///
  legend(cols(1) bplacement(5) ring(0))                   ///
  ylabel(, angle(horizontal)) xlabel(, grid)
graph export marginsplot.png, replace

putdocx paragraph, halign(center)
putdocx image marginsplot.png, height(3.5in)

putdocx save rpt1.docx, replace
