****************************************************************
**# Setup
****************************************************************
version 17
clear all

webuse nhanes2l, clear

describe age sex race height weight bmi highbp ///
         bpsystol bpdiast tcresult hdresult


****************************************************************
**# The updated -table- command
****************************************************************		 
		 		 
/* One-way tabulation */		 
table (highbp) ()
table () (highbp)


/* Two-way tabulation */
table (sex) (highbp)

/* Options for modifying the totals to be reported */
table (sex) (highbp), nototals
table (sex) (highbp), totals(highbp)
table (sex) (highbp), totals(sex)


/* Frequencies and percentages across levels of highbp */
table () (highbp),           ///
      statistic(frequency)   ///
	  statistic(percent)

	  
/* Frequencies and percentages across levels of sex and highbp */	  	  
table (sex) (highbp),        ///
      statistic(frequency)   ///
      statistic(percent)     ///
      nototals

/* Means and standard deviations of continuous variables 
   across levels of highbp */
table () (highbp), 			///
  statistic(mean age bmi)   ///
  statistic(sd age bmi)     

/* Means and standard deviations of continuous variables; 
   frequencies and percentages of factor variables */
table () (highbp), 			///
  statistic(mean age bmi)   ///
  statistic(sd age bmi)     ///
  statistic(fvfrequency sex) ///
  statistic(fvpercent sex)

/* Numeric and string formats */
table () (highbp), 			///
  statistic(mean age bmi)   ///
  statistic(sd age bmi)     ///
  statistic(fvfrequency sex) ///
  statistic(fvpercent sex)   ///
  nformat(%5.2f mean sd)    ///
  sformat("(%s%%)" fvpercent) ///
  sformat("(%s)" sd)

  
/* Modify order of variables and statistics in the rows */  
table (var result) (highbp), 			///
  statistic(mean age bmi)   ///
  statistic(sd age bmi)     ///
  statistic(fvfrequency sex) ///
  statistic(fvpercent sex)   ///
  nformat(%5.2f mean sd)    ///
  sformat("(%s%%)" fvpercent) ///
  sformat("(%s)" sd)

/* Bonus */ 

/* Multiple variables in rows and columns */
table (sex hlthstat) (highbp region), nototals

/* Third set of parentheses for separate tables */
table (sex) (hlthstat) (highbp)

/* The -command()- option puts results from any Stata commands
   into the table */
table (colname result) (highbp), ///
      command(_r_b _r_se: regress bpsystol age weight)
 
  
****************************************************************
**# The new -etable- command 
****************************************************************  

/* Table of results for a single model */  
logistic highbp bmi age
etable

/* Modify the reported statistics */
etable, cstat(_r_b) cstat(_r_ci)

/* Change the format of the statistics */
etable, cstat(_r_b) cstat(_r_ci, cidelimiter(", ") nformat(%4.2f))

/* Add stars and a note explaining the levels */
etable, showstars showstarsnote

/* Modify the model statistics to be reported */
etable, mstat(aic) mstat(bic)


/* Table of results comparing multiple models */
logistic highbp bmi age 
etable, mstat(aic) mstat(bic)
logistic highbp bmi age i.sex
etable, append
logistic highbp bmi c.age##i.sex
etable, append

/* Add a title, notes, and update the column headers */
etable, replay column(index) ///
  title("Table 2: Logistic regression results") ///
  notes("Odds ratio (Std. Err.)")

  
****************************************************************
**# The new -collect- suite
****************************************************************  

/* Collections are built on results stored in e() and r() */
ttest age, by(highbp)
return list

/* Clear any previous collection from memory */
collect clear

/* Store results of 3 -ttest- commands in the default collection;
   specify that we want the mean for each group and the p-value
   to be automatically displayed in our tables */
collect r(mu_1) r(mu_2) r(p): ttest age, by(highbp)
collect r(mu_1) r(mu_2) r(p): ttest weight, by(highbp)
collect r(mu_1) r(mu_2) r(p): ttest bmi, by(highbp)


/* List all dimensions */
collect dims

/* List levels of the result and cmdset dimensions */
collect label list result, all
collect label list cmdset, all

/* Lay out a table with cmdset on the rows and result on the columns */
collect layout (cmdset) (result)

/* Alternative collection method--create a dimension with meaningful names*/
collect clear
collect r(mu_1) r(mu_2) r(p), tags(varname[age]): ttest age, by(highbp)
collect r(mu_1) r(mu_2) r(p), tags(varname[weight]): ttest weight, by(highbp)
collect r(mu_1) r(mu_2) r(p), tags(varname[bmi]): ttest bmi, by(highbp)

/* Verify that we see the expected varname dimension 
   with levels age, weight, and bmi */
collect dims
collect label list varname, all

/* Lay out our table again using the new varname dimension */
collect layout (varname) (result)

/* Modify the labels */
collect label levels result ///
  mu_1 "Normotensive" mu_2 "Hypertensive" p "p-value", modify
collect preview

/* Modify the format of p-values */
collect style cell result[p], nformat(%5.3f) min(0.001)
collect preview

/* Modify the format of means */
collect style cell result[mu_1 mu_2], nformat(%5.2f)
collect preview

/* Horizontally center the values */
collect style cell cell_type[item], halign(center)
collect preview

/* Remove the vertical border to the right of row headers */
collect style cell border_block, border(right, pattern(nil))
collect preview

/* Export the table to HTML */
collect export ttest_tab.html, replace

/* Save the style */
collect style save ttest_style, replace


/* Apply the same style to a table created with another dataset */
clear all
sysuse auto, clear
collect r(mu_1) r(mu_2) r(p), tags(varname[price]): ttest price, by(foreign)
collect r(mu_1) r(mu_2) r(p), tags(varname[weight]): ttest weight, by(foreign)
collect r(mu_1) r(mu_2) r(p), tags(varname[length]): ttest length, by(foreign)
collect style use ttest_style, replace
collect preview

/* Modify data-specific labels */
collect label levels result ///
  mu_1 "Domestic cars" mu_2 "Foreign cars" p "p-value", modify
collect preview


/* Use -collect- commands to modify -table- results */

webuse nhanes2l, clear
table (var) (highbp), ///
  statistic(mean age bmi) ///
  statistic(sd age bmi) ///
  statistic(fvfrequency sex race hlthstat) ///
  statistic(fvpercent sex race hlthstat) ///
  statistic(mean tcresult tgresult hdresult) ///
  statistic(sd tcresult tgresult hdresult) ///
  nformat(%5.2f mean sd) ///
  sformat("(%s%%)" fvpercent) ///
  sformat("(%s)" sd)

/* Put means, SDs, frequencies, and percents in one cell */  
collect composite define mystat = mean sd fvfrequency fvpercent, trim

/* Hide the names of the statistics */
collect style header result, level(hide)

/* Include only the new mystat result in the table */
collect layout (var) (highbp#result[mystat])

/* Modify organization of row headrs for factor variables */
collect style row stack, nobinder spacer
collect preview

/* Modify labels */
collect label dim highbp "Hypertension", modify
collect label levels highbp 0 "No" 1 "Yes"
collect preview

/* Add title and notes */
collect notes 1: Mean and standard deviation reported for continuous variables.
collect notes 2: Frequency and percentage reported for categorical variables.
collect title "Table 1: Summary statistics"
collect preview


/* Modify -etable- results using -collect- */  
quietly logistic highbp bmi age 
quietly etable
quietly logistic highbp bmi age i.sex
quietly etable, append
quietly logistic highbp bmi c.age##i.sex
etable, append column(index) ///
  mstat(aic) mstat(bic) ///
  title("Table 2: Logistic regression results") /// 
  notes("Odds ratio (Std. Err.)")

/* Hide variable name for factor variables; 
   change interaction notation from # to X */  
collect style header sex, title(hide)
collect style row split, dups(first) delimiter(" x ") spacer 
collect preview
